# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #
# pylint: disable=W0201

from typing import List
from ..protobufs import main_pb2
from .translate_message import TranslateMessage


class TranslateResult:
    """
    Represents a result of a G-code block translation.
    """

    @property
    def commands(self) -> List[str]:
        """
        Stream commands resulting from the block.
        """

        return self._commands

    @commands.setter
    def commands(self, value: List[str]) -> None:
        self._commands = value

    @property
    def warnings(self) -> List[TranslateMessage]:
        """
        Messages informing about unsupported codes and features.
        """

        return self._warnings

    @warnings.setter
    def warnings(self, value: List[TranslateMessage]) -> None:
        self._warnings = value

    def __repr__(self) -> str:
        return str(self.__dict__)

    @staticmethod
    def from_protobuf(
        pb_data: main_pb2.TranslatorTranslateResponse
    ) -> 'TranslateResult':
        instance = TranslateResult.__new__(
            TranslateResult
        )  # type: TranslateResult
        instance.commands = list(pb_data.commands)
        instance.warnings = [TranslateMessage.from_protobuf(item) for item in pb_data.warnings]
        return instance



from .axis_mapping import AxisMapping
from .translate_message import TranslateMessage
from .translate_result import TranslateResult
from .translator_axis_definition import TranslatorAxisDefinition
from .translator_config import TranslatorConfig
from .translator_definition import TranslatorDefinition
from .translator import Translator
from .translator_live import TranslatorLive



# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #
# pylint: disable=W0201

from typing import List, Optional
from ..protobufs import main_pb2
from ..measurement import Measurement
from .axis_mapping import AxisMapping


class TranslatorConfig:
    """
    Configuration of translator.
    """

    def __init__(
            self: 'TranslatorConfig',
            traverse_rate: Measurement,
            axes_mapping: Optional[List[AxisMapping]] = None
    ) -> None:
        self._traverse_rate = traverse_rate
        self._axes_mapping = axes_mapping

    @property
    def traverse_rate(self) -> Measurement:
        """
        Speed at which the device moves when traversing (G0).
        """

        return self._traverse_rate

    @traverse_rate.setter
    def traverse_rate(self, value: Measurement) -> None:
        self._traverse_rate = value

    @property
    def axes_mapping(self) -> Optional[List[AxisMapping]]:
        """
        Optional custom mapping of translator axes to stream axes.
        """

        return self._axes_mapping

    @axes_mapping.setter
    def axes_mapping(self, value: Optional[List[AxisMapping]]) -> None:
        self._axes_mapping = value

    def __repr__(self) -> str:
        return str(self.__dict__)

    @staticmethod
    def to_protobuf(source: 'TranslatorConfig') -> main_pb2.TranslatorConfig:
        if not isinstance(source, TranslatorConfig):
            raise TypeError("Provided value is not TranslatorConfig.")

        pb_data = main_pb2.TranslatorConfig()
        pb_data.traverse_rate.CopyFrom(Measurement.to_protobuf(source.traverse_rate))
        if source.axes_mapping is not None:
            pb_data.axes_mapping.extend([AxisMapping.to_protobuf(item) for item in source.axes_mapping])
        return pb_data



# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #
# pylint: disable=W0201

from typing import List
from ..protobufs import main_pb2
from .translator_axis_definition import TranslatorAxisDefinition


class TranslatorDefinition:
    """
    Defines an axis of the translator.
    """

    def __init__(
            self: 'TranslatorDefinition',
            device_id: int,
            axes: List[TranslatorAxisDefinition]
    ) -> None:
        self._device_id = device_id
        self._axes = axes

    @property
    def device_id(self) -> int:
        """
        Device ID of the controller.
        Can be obtained from device settings.
        """

        return self._device_id

    @device_id.setter
    def device_id(self, value: int) -> None:
        self._device_id = value

    @property
    def axes(self) -> List[TranslatorAxisDefinition]:
        """
        Axes of translator.
        """

        return self._axes

    @axes.setter
    def axes(self, value: List[TranslatorAxisDefinition]) -> None:
        self._axes = value

    def __repr__(self) -> str:
        return str(self.__dict__)

    @staticmethod
    def to_protobuf(source: 'TranslatorDefinition') -> main_pb2.TranslatorDefinition:
        if not isinstance(source, TranslatorDefinition):
            raise TypeError("Provided value is not TranslatorDefinition.")

        pb_data = main_pb2.TranslatorDefinition()
        pb_data.device_id = source.device_id
        if source.axes is not None:
            pb_data.axes.extend([TranslatorAxisDefinition.to_protobuf(item) for item in source.axes])
        return pb_data



# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #
# pylint: disable=W0201

from ..protobufs import main_pb2


class TranslateMessage:
    """
    Represents a message from translator regarding a block translation.
    """

    @property
    def message(self) -> str:
        """
        The message describing an occurrence.
        """

        return self._message

    @message.setter
    def message(self, value: str) -> None:
        self._message = value

    @property
    def from_block(self) -> int:
        """
        The index in the block string that the message regards to.
        """

        return self._from_block

    @from_block.setter
    def from_block(self, value: int) -> None:
        self._from_block = value

    @property
    def to_block(self) -> int:
        """
        The end index in the block string that the message regards to.
        The end index is exclusive.
        """

        return self._to_block

    @to_block.setter
    def to_block(self, value: int) -> None:
        self._to_block = value

    def __repr__(self) -> str:
        return str(self.__dict__)

    @staticmethod
    def from_protobuf(
        pb_data: main_pb2.TranslateMessage
    ) -> 'TranslateMessage':
        instance = TranslateMessage.__new__(
            TranslateMessage
        )  # type: TranslateMessage
        instance.message = pb_data.message
        instance.from_block = pb_data.from_block
        instance.to_block = pb_data.to_block
        return instance
